@@ -10,14 +10,14 @@ import glob
 def reports_pdf_scheduler() -> None:
 
     logger.info("superset_pdf_report started")
-    jobspath = '{}*.json'.format(PDF_REPORT_JOB_FOLDER)
-    logger.info(jobspath)
-    joblist = glob.glob(jobspath)
+    joblist = glob.glob('{}*.json'.format(PDF_REPORT_JOB_FOLDER))
     logger.info(joblist)
 
     for job_name in joblist:
+        job = job_name.spit("/")[-1]
+        logger.info("Start Job: {}".format(job))
         pdf_report_task = PDF_report()
-        pdf_report_task.execute(job_name)
+        pdf_report_task.execute(job)
     
     
     logger.info("superset_pdf_report finished")
